@@ -8,13 +8,13 @@
 #include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <QApplication>
+#include <QGuiApplication>
 #include <QCommandLineParser>
 
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication app(argc, argv);
+    QGuiApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
     KAboutData aboutData(QStringLiteral("calindac"), i18n("Calindori Alarm Check Daemon"),
