@@ -34,6 +34,18 @@ public:
      * @param scheduledWakeup The scheduled wake up, as returned by the scheduleWakeup method
      */
     virtual void clearWakeup(const QVariant &scheduledWakeup) = 0;
+
+    /**
+     *
+     * @return True if the backend is a valid one
+     */
+    virtual bool isValid() = 0;
+
+    /**
+     * @return True if the backend offers wakeup features
+     */
+    virtual bool isWakeupBackend() = 0;
+
 };
 
 #endif // WAKEUPBACKEND_H
