@@ -26,6 +26,8 @@ public:
     void scheduleAlarmCheck();
 
 private:
+#ifndef Q_OS_ANDROID
     QDBusInterface *m_interface;
+#endif
 };
 #endif //ALARM_CHECKER_H
