@@ -9,10 +9,11 @@
 #include <KLocalizedString>
 #include <KPeople/PersonData>
 
+#include "calendarcontroller.h"
+
 AttendeesModel::AttendeesModel(QObject *parent) : QAbstractListModel {parent}, m_attendees {KCalendarCore::Attendee::List {}}
 {
     connect(this, &AttendeesModel::uidChanged, this, &AttendeesModel::loadPersistentData);
-    connect(this, &AttendeesModel::calendarChanged, this, &AttendeesModel::loadPersistentData);
 }
 
 QHash<int, QByteArray> AttendeesModel::roleNames() const
@@ -42,20 +43,6 @@ void AttendeesModel::setUid(const QString &uid)
     }
 }
 
-LocalCalendar *AttendeesModel::calendar() const
-{
-    return m_calendar;
-}
-
-void AttendeesModel::setCalendar(LocalCalendar *calendarPtr)
-{
-    if (m_calendar != calendarPtr) {
-        m_calendar = calendarPtr;
-
-        Q_EMIT calendarChanged();
-    }
-}
-
 QVariant AttendeesModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
@@ -101,8 +88,8 @@ void AttendeesModel::loadPersistentData()
     KCalendarCore::Calendar::Ptr calendar;
 
     m_attendees.clear();
-    if (m_calendar != nullptr && !m_uid.isEmpty()) {
-        incidence = m_calendar->calendar()->incidence(m_uid);
+    if (!m_uid.isEmpty()) {
+        incidence = CalendarController::instance().activeCalendar()->calendar()->incidence(m_uid);
         if (incidence != nullptr) {
             m_attendees = incidence->attendees();
         }
@@ -175,16 +162,16 @@ QString AttendeesModel::statusIcon(const int row) const
 {
     switch (m_attendees.at(row).status()) {
     case KCalendarCore::Attendee::PartStat::Accepted: {
-        return "meeting-attending";
+        return QStringLiteral("meeting-attending");
     }
     case KCalendarCore::Attendee::PartStat::Tentative: {
-        return "meeting-attending-tentative";
+        return QStringLiteral("meeting-attending-tentative");
     }
     case KCalendarCore::Attendee::PartStat::Declined: {
-        return "meeting-participant-no-response";
+        return QStringLiteral("meeting-participant-no-response");
     }
     default: {
-        return "meeting-participant-request-response";
+        return QStringLiteral("meeting-participant-request-response");
     }
     }
 }
